@@ -16,14 +16,6 @@ def log(*variables):
 
     frame_data = get_frame_data()
 
-    if frame_data is None:
-        shell_error_message = '''
-        This function does not work in Python interactive shell.
-        Try it inside a Python file.
-        '''
-        print(shell_error_message)
-        return
-
     log_header = make_header(frame_data)
 
     if variables:
